package com.persagy.mq;

import org.springframework.amqp.core.Binding;
import org.springframework.amqp.core.BindingBuilder;
import org.springframework.amqp.core.Queue;
import org.springframework.amqp.core.TopicExchange;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * RabbitConfig
 * 
 * @author gaoyu
 *
 */
@Configuration
public class RabbitConfig {
	/**
	 * 交换机
	 */
	public static final String exchange = "exchange-msg-service";

	/**
	 * 报警消息路由键
	 */
	public static final String alarmMsgRoutingKey = "alarm-msg-routing-key";

	/**
	 * 报警条件队列
	 */
	private final String alarmMsgQueue = "alarm-msg-queue";

	@Bean
	public Queue alarmMsgQueue() {
		return new Queue(alarmMsgQueue, true);
	}

	@Bean
	public TopicExchange alarmServiceExchange() {
		return new TopicExchange(exchange);
	}

	@Bean
	public Binding conditionBinding() {
		return BindingBuilder.bind(alarmMsgQueue()).to(alarmServiceExchange()).with(alarmMsgRoutingKey);
	}

}
